# Copyrights 2001-2009 by Mark Overmeer.
#  For other contributors see ChangeLog.
# See the manual pages for details on the licensing terms.
# Pod stripped from pm file by OODoc 1.06.

package MailBox::Test::12head::Definition;
use vars '$VERSION';
$VERSION = '2.093';


sub name     {"Mail::Message::Head; message headers"}
sub critical {1}
sub skip     { undef }

1;
